# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ab-test-toolkit',
                'doc_host': 'https://k111git.github.io',
                'git_url': 'https://github.com/k111git/ab-test-toolkit',
                'lib_path': 'ab_test_toolkit'},
  'syms': { 'ab_test_toolkit.generator': { 'ab_test_toolkit.generator.data_to_contingency': ( 'data_generation.html#data_to_contingency',
                                                                                              'ab_test_toolkit/generator.py'),
                                           'ab_test_toolkit.generator.generate_binary_data': ( 'data_generation.html#generate_binary_data',
                                                                                               'ab_test_toolkit/generator.py'),
                                           'ab_test_toolkit.generator.generate_contingency': ( 'data_generation.html#generate_contingency',
                                                                                               'ab_test_toolkit/generator.py'),
                                           'ab_test_toolkit.generator.generate_continuous_data': ( 'data_generation.html#generate_continuous_data',
                                                                                                   'ab_test_toolkit/generator.py')},
            'ab_test_toolkit.plotting': { 'ab_test_toolkit.plotting.plot_betas': ( 'plotting.html#plot_betas',
                                                                                   'ab_test_toolkit/plotting.py'),
                                          'ab_test_toolkit.plotting.plot_binary_power': ( 'plotting.html#plot_binary_power',
                                                                                          'ab_test_toolkit/plotting.py'),
                                          'ab_test_toolkit.plotting.plot_continuous_power': ( 'plotting.html#plot_continuous_power',
                                                                                              'ab_test_toolkit/plotting.py'),
                                          'ab_test_toolkit.plotting.plot_distribution': ( 'plotting.html#plot_distribution',
                                                                                          'ab_test_toolkit/plotting.py'),
                                          'ab_test_toolkit.plotting.plot_power': ( 'plotting.html#plot_power',
                                                                                   'ab_test_toolkit/plotting.py')},
            'ab_test_toolkit.power': { 'ab_test_toolkit.power._compute_sample_size_from_powerline': ( 'power.html#_compute_sample_size_from_powerline',
                                                                                                      'ab_test_toolkit/power.py'),
                                       'ab_test_toolkit.power.sample_size_binary': ( 'power.html#sample_size_binary',
                                                                                     'ab_test_toolkit/power.py'),
                                       'ab_test_toolkit.power.sample_size_continuous': ( 'power.html#sample_size_continuous',
                                                                                         'ab_test_toolkit/power.py'),
                                       'ab_test_toolkit.power.simulate_power_binary': ( 'power.html#simulate_power_binary',
                                                                                        'ab_test_toolkit/power.py'),
                                       'ab_test_toolkit.power.simulate_power_continuous': ( 'power.html#simulate_power_continuous',
                                                                                            'ab_test_toolkit/power.py')},
            'ab_test_toolkit.wrappers': {'ab_test_toolkit.wrappers.hello': ('wrappers.html#hello', 'ab_test_toolkit/wrappers.py')}}}
